@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,6 +14,7 @@ import mock
 import os
 import tempfile
 
+from oslo_concurrency import processutils as putils
 import six
 
 from os_brick import exception
@@ -28,7 +27,8 @@ class RemoteFsClientTestCase(base.TestCase):
 
     def setUp(self):
         super(RemoteFsClientTestCase, self).setUp()
-        self.mock_execute = mock.patch.object(priv_rootwrap, 'execute').start()
+        self.mock_execute = self.mock_object(priv_rootwrap, 'execute',
+                                             return_value=None)
 
     @mock.patch.object(remotefs.RemoteFsClient, '_read_mounts',
                        return_value=[])
@@ -78,9 +78,10 @@ class RemoteFsClientTestCase(base.TestCase):
                            run_as_root=True)]
         self.mock_execute.assert_has_calls(calls)
 
+    @mock.patch('os.path.exists', return_value=False)
     @mock.patch.object(remotefs.RemoteFsClient, '_read_mounts',
                        return_value=[])
-    def test_vzstorage_with_mds_list(self, mock_read_mounts):
+    def test_vzstorage_with_mds_list(self, mock_read_mounts, mock_exists):
         client = remotefs.RemoteFsClient("vzstorage", root_helper='true',
                                          vzstorage_mount_point_base='/mnt')
         cluster_name = 'qwe'
@@ -215,11 +216,12 @@ class ScalityRemoteFsClientTestCase(base.TestCase):
             'scality', root_helper='true', scality_mount_point_base='/fake')
         self.assertEqual('/fake/path/00', fsclient.get_mount_point('path'))
 
-    @mock.patch('oslo_concurrency.processutils.execute')
+    @mock.patch('oslo_concurrency.processutils.execute', return_value=None)
     @mock.patch('os_brick.remotefs.remotefs.RemoteFsClient._do_mount')
     def test_mount(self, mock_do_mount, mock_execute):
         fsclient = remotefs.ScalityRemoteFsClient(
-            'scality', root_helper='true', scality_mount_point_base='/fake')
+            'scality', root_helper='true', scality_mount_point_base='/fake',
+            execute=putils.execute)
         with mock.patch.object(fsclient, '_read_mounts', return_value={}):
             fsclient.mount('fake')
 
